@@ -115,6 +115,7 @@ struct _TerminalApp
   int n_clipboard_targets;
 
   gboolean unified_menu;
+  gboolean use_headerbar;
 };
 
 enum
@@ -558,7 +559,8 @@ clipboard_owner_change_cb (GtkClipboard *clipboard,
                                  app);
 }
 
-/* App menu callbacks */
+/* Callbacks from former app menu.
+ * The preferences one is still used with the "--preferences" cmdline option. */
 
 static void
 app_menu_preferences_cb (GSimpleAction *action,
@@ -617,7 +619,6 @@ static void
 terminal_app_startup (GApplication *application)
 {
   TerminalApp *app = TERMINAL_APP (application);
-  GtkApplication *gtk_application = GTK_APPLICATION (application);
   const GActionEntry action_entries[] = {
     { "preferences", app_menu_preferences_cb,   NULL, NULL, NULL },
     { "help",        app_menu_help_cb,          NULL, NULL, NULL },
@@ -638,18 +639,12 @@ terminal_app_startup (GApplication *application)
 
   app_load_css (application);
 
-  /* Figure out whether the shell shows appmenu/menubar */
-  gboolean shell_shows_appmenu, shell_shows_menubar;
+  /* Figure out whether the shell shows the menubar */
+  gboolean shell_shows_menubar;
   g_object_get (gtk_settings_get_default (),
-                "gtk-shell-shows-app-menu", &shell_shows_appmenu,
                 "gtk-shell-shows-menubar", &shell_shows_menubar,
                 NULL);
 
-  /* App menu */
-  GMenu *appmenu_new_terminal_section = gtk_application_get_menu_by_id (gtk_application,
-                                                                        "new-terminal-section");
-  fill_new_terminal_section (app, appmenu_new_terminal_section, NULL, 0); /* no submenu */
-
   /* Menubar */
   /* If the menubar is shown by the shell, omit mnemonics for the submenus. This is because Alt+F etc.
    * are more important to be usable in the terminal, the menu cannot be replaced runtime (to toggle
@@ -676,11 +671,7 @@ terminal_app_startup (GApplication *application)
   /* Install the encodings submenu */
   terminal_encodings_append_menu (app->menubar_set_encoding_submenu);
 
-  /* Show/hide the appmenu/menubar as appropriate:
-   * If the shell wants to show the menubar, make it available.
-   * If the shell wants to show both the appmenu and the menubar, there's no need for the appmenu. */
-  if (shell_shows_appmenu && shell_shows_menubar)
-    gtk_application_set_app_menu (GTK_APPLICATION (app), NULL);
+  /* Show/hide the menubar as appropriate: If the shell wants to show the menubar, make it available. */
   if (shell_shows_menubar)
     gtk_application_set_menubar (GTK_APPLICATION (app), app->menubar);
 
@@ -710,10 +701,11 @@ terminal_app_init (TerminalApp *app)
                                                      GTK_DEBUG_ENABLE_INSPECTOR_KEY,
                                                      GTK_DEBUG_ENABLE_INSPECTOR_TYPE);
 
-  /* This is an internal setting that exists only for distributions
-   * to override, so we cache it on startup and don't react to changes.
+  /* These are internal settings that exists only for distributions
+   * to override, so we cache them on startup and don't react to changes.
    */
-  app->unified_menu = g_settings_get_boolean (app->global_settings, TERMINAL_SETTING_UNIFIED_MENU);
+  app->unified_menu = g_settings_get_boolean (app->global_settings, TERMINAL_SETTING_UNIFIED_MENU_KEY);
+  app->use_headerbar = g_settings_get_boolean (app->global_settings, TERMINAL_SETTING_HEADERBAR_KEY);
 
 #if GTK_CHECK_VERSION (3, 19, 0)
   GtkSettings *gtk_settings = gtk_settings_get_default ();
@@ -1172,3 +1164,11 @@ terminal_app_get_menu_unified (TerminalApp *app)
 
   return app->unified_menu;
 }
+
+gboolean
+terminal_app_get_use_headerbar (TerminalApp *app)
+{
+  g_return_val_if_fail (TERMINAL_IS_APP (app), FALSE);
+
+  return app->use_headerbar;
+}
