@@ -585,7 +585,6 @@ listbox_add_all_profiles (PrefData *data)
 
   for (l = list; l != NULL; l = l->next) {
     GSettings *profile = (GSettings *) l->data;
-    gs_free gchar *text = g_settings_get_string (profile, TERMINAL_PROFILE_VISIBLE_NAME_KEY);
     gs_free gchar *uuid = terminal_settings_list_dup_uuid_from_child (data->profiles_list, profile);
 
     row = listbox_create_row (NULL,
@@ -849,16 +848,16 @@ terminal_prefs_show_preferences (GSettings *profile, const char *widget_name)
   gtk_widget_set_visible (theme_variant_combo, FALSE);
 #endif /* GTK+ 3.19 */
 
-#ifndef DISUNIFY_NEW_TERMINAL_SECTION
-  g_settings_bind (settings,
-                   TERMINAL_SETTING_NEW_TERMINAL_MODE_KEY,
-                   new_terminal_mode_combo,
-                   "active-id",
-                   G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
-#else
-  gtk_widget_set_visible (new_terminal_mode_label, FALSE);
-  gtk_widget_set_visible (new_terminal_mode_combo, FALSE);
-#endif
+  if (terminal_app_get_menu_unified (app)) {
+    g_settings_bind (settings,
+                     TERMINAL_SETTING_NEW_TERMINAL_MODE_KEY,
+                     new_terminal_mode_combo,
+                     "active-id",
+                     G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+  } else {
+    gtk_widget_set_visible (new_terminal_mode_label, FALSE);
+    gtk_widget_set_visible (new_terminal_mode_combo, FALSE);
+  }
 
   if (shell_shows_menubar) {
     gtk_widget_set_visible (disable_mnemonics_button, FALSE);
