@@ -104,8 +104,6 @@ void         terminal_screen_set_initial_environment (TerminalScreen  *screen,
 char **      terminal_screen_get_initial_environment (TerminalScreen  *screen);
 
 const char* terminal_screen_get_title          (TerminalScreen *screen);
-const char* terminal_screen_get_icon_title     (TerminalScreen *screen);
-gboolean    terminal_screen_get_icon_title_set (TerminalScreen *screen);
 
 char *terminal_screen_get_current_dir (TerminalScreen *screen);
 
